import type { SliceHelper, PropId, PropIds, MapEntity } from './types';
import { LoadingItemState, LoadingPayload } from './create-loader';
export declare type LoaderTableState<M extends Record<string, any> = Record<string, any>> = MapEntity<LoadingItemState<M>>;
export interface LoadingState<M extends Record<string, any> = Record<string, any>> extends LoadingItemState<M> {
    isError: boolean;
    isSuccess: boolean;
    isIdle: boolean;
    isLoading: boolean;
    isInitialLoading: boolean;
}
export declare const defaultLoader: (l?: Partial<LoadingItemState>) => LoadingState;
export declare type LoadingMapPayload<M extends Record<string, any> = Record<string, any>> = LoadingPayload<M> & {
    id: string;
};
export interface LoaderTableSelectors<S = any> {
    findById: (d: LoaderTableState, { id }: PropId) => LoadingState;
    findByIds: (d: LoaderTableState, { ids }: PropIds) => LoadingState[];
    selectTable: (s: S) => LoaderTableState;
    selectById: (s: S, p: PropId) => LoadingState;
    selectByIds: (s: S, p: {
        ids: string[];
    }) => LoadingState[];
}
export declare function loaderTableSelectors<S = any>(selectTable: (s: S) => LoaderTableState): LoaderTableSelectors<S>;
export default function createLoaderTable<M extends Record<string, any> = Record<string, any>>({ name, initialState, extraReducers, }: SliceHelper<LoaderTableState<M>>): {
    getSelectors: <S>(stateFn: (s: S) => LoaderTableState<M>) => LoaderTableSelectors<S>;
    name: string;
    reducer: import("./types").Reducer<LoaderTableState<M>, import("./types").Action<any, string>>;
    actions: {
        loading: (payload: LoadingMapPayload<M>) => import("./types").Action<LoadingMapPayload<M>, string>;
        success: (payload: LoadingMapPayload<M>) => import("./types").Action<LoadingMapPayload<M>, string>;
        error: (payload: LoadingMapPayload<M>) => import("./types").Action<LoadingMapPayload<M>, string>;
        remove: (payload: string[]) => import("./types").Action<string[], string>;
        resetById: (payload: string) => import("./types").Action<string, string>;
        resetAll: () => import("./types").Action<any, string>;
    };
    toString: () => string;
};
