"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.loaderTableSelectors = exports.defaultLoader = void 0;
var reselect_1 = require("reselect");
var create_slice_1 = __importDefault(require("./create-slice"));
var types_1 = require("./types");
var create_map_1 = require("./create-map");
var create_loader_1 = require("./create-loader");
var defaultLoader = function (l) {
    if (l === void 0) { l = {}; }
    var loading = (0, create_loader_1.defaultLoadingItem)(l);
    return __assign(__assign({}, loading), { isIdle: loading.status === 'idle', isError: loading.status === 'error', isSuccess: loading.status === 'success', isLoading: loading.status === 'loading', isInitialLoading: (loading.status === 'idle' || loading.status === 'loading') &&
            loading.lastSuccess === 0 });
};
exports.defaultLoader = defaultLoader;
function reducerCreator(reducer) {
    return function (state, payload) {
        var _a;
        return (__assign(__assign({}, state), (_a = {}, _a[payload.id] = reducer(state[payload.id], payload), _a)));
    };
}
function loaderTableSelectors(selectTable) {
    var findById = function (data, _a) {
        if (data === void 0) { data = {}; }
        var id = _a.id;
        return (0, exports.defaultLoader)(data[id]);
    };
    var findByIds = function (data, _a) {
        var ids = _a.ids;
        return ids
            .map(function (id) { return data[id]; })
            .filter(types_1.excludesFalse)
            .map(function (loader) { return (0, exports.defaultLoader)(loader); });
    };
    var selectById = (0, reselect_1.createSelector)(selectTable, function (_, p) { return p.id; }, function (loaders, id) { return findById(loaders, { id: id }); });
    var selectByIds = (0, reselect_1.createSelector)(selectTable, function (_, p) { return p.ids; }, function (loaders, ids) { return findByIds(loaders, { ids: ids }); });
    return {
        findById: findById,
        findByIds: findByIds,
        selectTable: selectTable,
        selectById: selectById,
        selectByIds: selectByIds,
    };
}
exports.loaderTableSelectors = loaderTableSelectors;
function createLoaderTable(_a) {
    var name = _a.name, _b = _a.initialState, initialState = _b === void 0 ? {} : _b, extraReducers = _a.extraReducers;
    var loading = (0, create_loader_1.loadingReducers)((0, create_loader_1.defaultLoadingItem)());
    var map = (0, create_map_1.mapReducers)(initialState);
    var slice = (0, create_slice_1.default)({
        name: name,
        initialState: initialState,
        extraReducers: extraReducers,
        useImmer: false,
        reducers: {
            loading: reducerCreator(loading.loading),
            success: reducerCreator(loading.success),
            error: reducerCreator(loading.error),
            resetById: function (state, id) {
                var _a;
                return (__assign(__assign({}, state), (_a = {}, _a[id] = loading.reset(), _a)));
            },
            remove: map.remove,
            resetAll: map.reset,
        },
    });
    return __assign(__assign({}, slice), { getSelectors: function (stateFn) {
            return loaderTableSelectors(stateFn);
        } });
}
exports.default = createLoaderTable;
//# sourceMappingURL=create-loader-table.js.map