import type { AnyState, MapEntity, PatchEntity, SliceHelper, PropId, PropIds } from './types';
export interface TableSelectors<Entity extends AnyState = AnyState, S = any> {
    findById: (d: MapEntity<Entity>, { id }: PropId) => Entity | undefined;
    findByIds: (d: MapEntity<Entity>, { ids }: PropIds) => Entity[];
    tableAsList: (d: MapEntity<Entity>) => Entity[];
    selectTable: (s: S) => MapEntity<Entity>;
    selectTableAsList: (state: S) => Entity[];
    selectById: (s: S, p: PropId) => Entity | undefined;
    selectByIds: (s: S, p: {
        ids: string[];
    }) => Entity[];
}
export declare function tableSelectors<Entity extends AnyState = AnyState, S = any>(selectTable: (s: S) => MapEntity<Entity>): TableSelectors<Entity, S>;
export declare function mustSelectEntity<Entity extends AnyState = AnyState>(defaultEntity: Entity | (() => Entity)): <S = any>(selectById: (s: S, p: PropId) => Entity | undefined) => (state: S, { id }: PropId) => Entity;
interface TableReducers<Entity extends AnyState = AnyState> {
    add: (state: MapEntity<Entity>, payload: MapEntity<Entity>) => MapEntity<Entity>;
    set: (state: MapEntity<Entity>, payload: MapEntity<Entity>) => MapEntity<Entity>;
    remove: (state: MapEntity<Entity>, payload: string[]) => MapEntity<Entity>;
    reset: (state: MapEntity<Entity>) => MapEntity<Entity>;
    merge: (state: MapEntity<Entity>, payload: PatchEntity<MapEntity<Entity>>) => MapEntity<Entity>;
    patch: (state: MapEntity<Entity>, payload: PatchEntity<MapEntity<Entity>>) => MapEntity<Entity>;
}
export declare function tableReducers<Entity extends AnyState = AnyState>(initialState?: MapEntity<Entity>): TableReducers<Entity>;
export declare function createTableAdapter<Entity extends AnyState = AnyState>(initialState?: MapEntity<Entity>): {
    reducers: TableReducers<Entity>;
    getSelectors: <S>(stateFn: (s: S) => MapEntity<Entity>) => TableSelectors<Entity, S>;
};
export default function createTable<Entity extends AnyState = AnyState>({ name, extraReducers, initialState, }: SliceHelper<MapEntity<Entity>>): {
    getSelectors: <S>(stateFn: (s: S) => MapEntity<Entity>) => TableSelectors<Entity, S>;
    name: string;
    reducer: import("./types").Reducer<MapEntity<Entity>, import("./types").Action<any, string>>;
    actions: {
        add: Object extends MapEntity<Entity> ? (payload?: any) => import("./types").Action<any, string> : (payload: MapEntity<Entity>) => import("./types").Action<MapEntity<Entity>, string>;
        set: Object extends MapEntity<Entity> ? (payload?: any) => import("./types").Action<any, string> : (payload: MapEntity<Entity>) => import("./types").Action<MapEntity<Entity>, string>;
        remove: (payload: string[]) => import("./types").Action<string[], string>;
        patch: Object extends PatchEntity<MapEntity<Entity>> ? (payload?: any) => import("./types").Action<any, string> : (payload: PatchEntity<MapEntity<Entity>>) => import("./types").Action<PatchEntity<MapEntity<Entity>>, string>;
        merge: Object extends PatchEntity<MapEntity<Entity>> ? (payload?: any) => import("./types").Action<any, string> : (payload: PatchEntity<MapEntity<Entity>>) => import("./types").Action<PatchEntity<MapEntity<Entity>>, string>;
        reset: () => import("./types").Action<any, string>;
    };
    toString: () => string;
};
export {};
