"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createTableAdapter = exports.tableReducers = exports.mustSelectEntity = exports.tableSelectors = void 0;
var reselect_1 = require("reselect");
var create_map_1 = require("./create-map");
var create_slice_1 = __importDefault(require("./create-slice"));
var types_1 = require("./types");
function tableSelectors(selectTable) {
    var tableAsList = function (data) {
        return Object.values(data).filter(types_1.excludesFalse);
    };
    var findById = function (data, _a) {
        var id = _a.id;
        return data[id];
    };
    var findByIds = function (data, _a) {
        var ids = _a.ids;
        return ids.map(function (id) { return data[id]; }).filter(types_1.excludesFalse);
    };
    var selectById = function (state, _a) {
        var id = _a.id;
        var data = selectTable(state);
        return findById(data, { id: id });
    };
    return {
        findById: findById,
        findByIds: findByIds,
        tableAsList: tableAsList,
        selectTable: selectTable,
        selectTableAsList: (0, reselect_1.createSelector)(selectTable, function (data) {
            return tableAsList(data);
        }),
        selectById: selectById,
        selectByIds: (0, reselect_1.createSelector)(selectTable, function (_, p) { return p.ids; }, function (tbl, ids) { return findByIds(tbl, { ids: ids }); }),
    };
}
exports.tableSelectors = tableSelectors;
function mustSelectEntity(defaultEntity) {
    var isFn = typeof defaultEntity === 'function';
    return function selectEntity(selectById) {
        return function (state, _a) {
            var id = _a.id;
            if (isFn) {
                var entity = defaultEntity;
                return selectById(state, { id: id }) || entity();
            }
            return selectById(state, { id: id }) || defaultEntity;
        };
    };
}
exports.mustSelectEntity = mustSelectEntity;
function tableReducers(initialState) {
    if (initialState === void 0) { initialState = {}; }
    return (0, create_map_1.mapReducers)(initialState);
}
exports.tableReducers = tableReducers;
function createTableAdapter(initialState) {
    if (initialState === void 0) { initialState = {}; }
    var reducers = tableReducers(initialState);
    return {
        reducers: reducers,
        getSelectors: function (stateFn) {
            return tableSelectors(stateFn);
        },
    };
}
exports.createTableAdapter = createTableAdapter;
function createTable(_a) {
    var name = _a.name, extraReducers = _a.extraReducers, _b = _a.initialState, initialState = _b === void 0 ? {} : _b;
    var _c = createTableAdapter(initialState), reducers = _c.reducers, adapter = __rest(_c, ["reducers"]);
    var slice = (0, create_slice_1.default)({
        name: name,
        initialState: initialState,
        extraReducers: extraReducers,
        reducers: reducers,
        useImmer: false,
    });
    return __assign(__assign({}, slice), adapter);
}
exports.default = createTable;
//# sourceMappingURL=create-table.js.map